.. Copyright 2017 TsumiNa. All rights reserved.


What is XenonPy project
========================
.. image:: https://badges.gitter.im/yoshida-lab/XenonPy.svg
    :alt: Join the chat at https://gitter.im/yoshida-lab/XenonPy
    :target: https://gitter.im/yoshida-lab/XenonPy?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

.. image:: https://travis-ci.org/yoshida-lab/XenonPy.svg?branch=master
    :alt: Build Status
    :target: https://travis-ci.org/yoshida-lab/XenonPy

**XenonPy** is a Python library focus on the material informatics which be designed for material explore based on machine learning.

The main purpose of this project is to build a complex system to calculate various chem/phys descriptors for machine learning then extend them to explore material space.
To reach this target, system also provide model training routines and try to re-use pre-trained model by various deep learning methods such as **transfer learning**.

This project has just started and a long way to run. The final goal of this project is to build a **All-In-One** virtual environment for material development come with:

* **Massive dataset and Pre-trained models out-of-box**
* **Various descriptor calculation methods**
* **Model training and re-use**
* **Combined with deep learning methods seamless**
* **Visualization tools for analysis and publish ready**

XenonPy inspired by matminer: https://hackingmaterials.github.io/matminer/.

XenonPy is a open source project https://github.com/yoshida-lab/XenonPy.

See our documents for details: http://xenonpy.readthedocs.io 


Contribution guidelines
=======================

* Discussion with others
* Docstring use `Numpy style`_.
* Check codes with Pylint
* Writing tests if possible

Contract
========

* With issues_
* With Gitter_



Copyright and license
=====================

Code and documentation © 2017 TsumiNa.
Released under the BSD-3 license.

.. _issues: https://github.com/yoshida-lab/XenonPy/issues
.. _Gitter: https://gitter.im/yoshida-lab/XenonPy
.. _Numpy style: https://github.com/numpy/numpy/blob/master/doc/HOWTO_DOCUMENT.rst.txt